==> sentry_stack_dingding-1.0.2-py3-none-any.whl: sentry_dingding/plugin.py <==
# coding: utf-8

import json

import requests
from sentry.plugins.bases.notify import NotificationPlugin

import sentry_dingding
from .forms import DingDingOptionsForm

DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"


class DingDingPlugin(NotificationPlugin):
    """
    Sentry plugin to send error counts to DingDing.
    """
    author = 'wilson-loo'
    author_url = 'https://github.com/wilsonloo/sentry-stack-dingding'
    version = sentry_dingding.VERSION
    description = 'Send error counts to DingDing.'
    resource_links = [
        ('Source', 'https://github.com/wilsonloo/sentry-stack-dingding.git'),
        ('Bug Tracker', 'https://github.com/wilsonloo/sentry-stack-dingding.git/issues'),
        ('README', 'https://github.com/wilsonloo/sentry-stack-dingding.git/blob/master/README.md'),
    ]

    slug = 'DingDing'
    title = 'DingDing'
    conf_key = slug
    conf_title = title
    project_conf_form = DingDingOptionsForm

    def is_configured(self, project):
        """
        Check if plugin is configured.
        """
        return bool(self.get_option('access_token', project)) and bool(self.get_option('stack_deep', project))

    def notify_users(self, group, event, *args, **kwargs):
        self.post_process(group, event, *args, **kwargs)

    def post_process(self, group, event, *args, **kwargs):
        """
        Process error.
        """
        if not self.is_configured(group.project):
            return

        if group.is_ignored():
            return

        access_token = self.get_option('access_token', group.project)
        send_url = DingTalk_API.format(token=access_token)
        title = u'【%s】的项目异常' % event.project.slug

        # splice stack
        stackDeep=self.get_option('stack_deep', group.project)
        stack=event.stack or ""
        stack_lines = stack.split('\n')
        selected_stack_lines = stack_lines[:stackDeep]
        stack = '\n'.join(selected_stack_lines)
        
        data = {
            "msgtype": "markdown",
            "markdown": {
                "title": title,
                "text": u"#### {title} \n\n > {message} \n\n {stack} \n\n [详细信息]({url})".format(
                    title=title,
                    message=event.message or event.title,
                    stack=stack,
                    url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                )
            }
        }
        requests.post(
            url=send_url,
            headers={"Content-Type": "application/json"},
            data=json.dumps(data).encode("utf-8")
        )

==> sentry_stack_dingding-1.0.4-py3-none-any.whl: sentry_dingding/plugin.py <==
# coding: utf-8

import json

import requests
from sentry.plugins.bases.notify import NotificationPlugin

import sentry_dingding
from .forms import DingDingOptionsForm

DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"


class DingDingPlugin(NotificationPlugin):
    """
    Sentry plugin to send error counts to DingDing.
    """
    author = 'wilson-loo'
    author_url = 'https://github.com/wilsonloo/sentry-stack-dingding'
    version = sentry_dingding.VERSION
    description = 'Send error counts to DingDing with stack preview'
    resource_links = [
        ('Source', 'https://github.com/wilsonloo/sentry-stack-dingding.git'),
        ('Bug Tracker', 'https://github.com/wilsonloo/sentry-stack-dingding.git/issues'),
        ('README', 'https://github.com/wilsonloo/sentry-stack-dingding.git/blob/master/README.md'),
    ]

    slug = 'DingDing'
    title = 'DingDing'
    conf_key = slug
    conf_title = title
    project_conf_form = DingDingOptionsForm

    def is_configured(self, project):
        """
        Check if plugin is configured.
        """
        return bool(self.get_option('access_token', project)) and bool(self.get_option('stack_deep', project))

    def notify_users(self, group, event, *args, **kwargs):
        self.post_process(group, event, *args, **kwargs)

    def post_process(self, group, event, *args, **kwargs):
        """
        Process error.
        """
        if not self.is_configured(group.project):
            return

        if group.is_ignored():
            return

        access_token = self.get_option('access_token', group.project)
        send_url = DingTalk_API.format(token=access_token)
        title = u'【%s】的项目异常' % event.project.slug

        # splice stack
        stackDeep=self.get_option('stack_deep', group.project)
        stack = ""
        if event.frames and len(event.frames) > 0:
            stack = event.frames[:stackDeep]
            stack = json.dumps(stack, indent=2)
        
        data = {
            "msgtype": "markdown",
            "markdown": {
                "title": title,
                "text": u"#### {title} \n\n > {message} \n\n {stack} \n\n [详细信息]({url})".format(
                    title=title,
                    message=event.message or event.title,
                    stack=stack,
                    url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                )
            }
        }
        requests.post(
            url=send_url,
            headers={"Content-Type": "application/json"},
            data=json.dumps(data).encode("utf-8")
        )
